##  Applicable Use Cases
SAP LeanIX recommends using the fact sheet type organization for all use cases, including the initial application portfolio assessment.
Especially for large transformation cases (e.g., application modernization or ERP transformation) in which you would use SAP LeanIX Architecture and Road Map Planning, organization is a central fact sheet type to reflect the planning and rolling out of technology changes to various business units or regions.
